pub struct PagedRequest<'a, T> { /* private fields */ }Expand description
A request that supports automatic pagination via the Link header.
This is used to fetch multiple pages of results (e.g., historical timelines) by following the “next” link provided by the server.
Implementations
Sourceimpl<'a, T: DeserializeOwned> PagedRequest<'a, T>
impl<'a, T: DeserializeOwned> PagedRequest<'a, T>
Sourcepub fn new(client: &'a MastodonClient, initial_url: String) -> Self
pub fn new(client: &'a MastodonClient, initial_url: String) -> Self
Creates a new PagedRequest starting at the given URL.